@@ -5,20 +5,20 @@ Flatland Diagram Editor
 import logging
 import logging.config
 import sys
+import atexit
 import argparse
 from pathlib import Path
 from flatland.xuml.xuml_classdiagram import XumlClassDiagram
 from flatland.xuml.xuml_statemachine_diagram import XumlStateMachineDiagram
+from flatland.configuration.config import Config
 from flatland import version
 
 _logpath = Path("flatland.log")
 
 
-def clean_up(diagnostic=False):
-    """Delete the log file and any other cleanup"""
-    if not diagnostic:
-        # If we didn't crash and no log is explicitly requested, delete it
-        _logpath.unlink(missing_ok=True)
+def clean_up():
+    """Normal and exception exit activities"""
+    _logpath.unlink(missing_ok=True)
 
 def get_logger():
     """Initiate the logger"""
@@ -60,15 +60,18 @@ def main():
     logger = get_logger()
     args = parse(sys.argv[1:])
 
+    if not args.log:
+        # If no log file is requested, remove the log file before termination
+        atexit.register(clean_up)
+
     if args.version:
         print(f'Flatland version: {version}')
-        clean_up(args.log)
         sys.exit(0)
 
     if args.colors:
+        Config(rebuild_db=args.rebuild)  # Do any configuration tasks necessary before starting up the app
         from flatland.drawing_domain.styledb import StyleDB
         StyleDB(print_colors=True, rebuild=args.rebuild)
-        clean_up(args.log)
         sys.exit(0)
 
     if args.examples or args.docs:
@@ -82,7 +85,6 @@ def main():
             if local_ex_path.exists():
                 logger.info("examples already exist in the current directory.")
                 if not args.docs:
-                    clean_up(args.log)
                     sys.exit(1)
             else:
                 shutil.copytree(ex_path, local_ex_path)  # Copy the example directory
@@ -91,7 +93,6 @@ def main():
         if args.docs:
             if local_docs_path.exists():
                 logger.error("documentation already exists in the current directory.")
-                clean_up(args.log)
                 sys.exit(1)
             import shutil
             shutil.copytree(docs_path, local_docs_path)
@@ -105,7 +106,6 @@ def main():
         model_path = Path(args.model)
         if not model_path.is_file():
             logger.error(f"Model file: {args.model} specified on command line not found")
-            clean_up(args.log)
             sys.exit(1)
     else:
         # TODO: Standard input is not yet supported, so this is a placeholder
@@ -116,7 +116,6 @@ def main():
     layout_path = Path(args.layout)
     if not layout_path.is_file():
         logger.error(f"Layout file: {args.layout} specified on command line not found")
-        clean_up(args.log)
         sys.exit(1)
 
     # output file: If no output file is specified, the generated diagram is provided as standard output
@@ -128,6 +127,7 @@ def main():
         # TODO: Since a default diagram file is always supplied via argparse above, this clause will never execute
         diagram_path = sys.stdout
 
+    Config(rebuild_db=args.rebuild)  # Do any configuration tasks necessary before starting up the app
     # Generate the xuml class diagram (we don't do anything with the returned variable yet)
     mtype = model_path.suffix
     if mtype == '.xmm' or mtype == '.xcm':
@@ -135,7 +135,6 @@ def main():
             xuml_model_path=model_path,
             flatland_layout_path=layout_path,
             diagram_file_path=diagram_path,
-            rebuild=args.rebuild,
             show_grid=args.grid,
             nodes_only=args.nodes_only,
             no_color=args.no_color,
@@ -145,7 +144,6 @@ def main():
             xuml_model_path=model_path,
             flatland_layout_path=layout_path,
             diagram_file_path=diagram_path,
-            rebuild=args.rebuild,
             show_grid=args.grid,
             nodes_only=args.nodes_only,
             no_color=args.no_color,
@@ -153,5 +151,6 @@ def main():
 
     logger.info("No problemo")  # We didn't die on an exception, basically
 
+
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
